<?php namespace Lib\Admin\User;

use Lib\Admin\User\Validation\UserUpdateValidator as UserUpdateValidator;
use Lib\Admin\User\Validation\UserCreateValidator as UserCreateValidator;
use Lib\Admin\User\UserGestion as UserGestion;
use View, Redirect, Request, Response, Session;

class UserController extends \Lib\Shared\BaseController {

	protected $update_validation;
	protected $gestion;
	
	public function __construct(
		UserUpdateValidator $update_validation, 
		UserCreateValidator $create_validation,
		UserGestion $gestion)
	{
		parent::__construct();
		$this->update_validation = $update_validation;
		$this->create_validation = $create_validation;
		$this->gestion = $gestion;
	}

	public function index()
	{
		return View::make('Admin.User.views.index', $this->gestion->index(3));
	}

	public function create()
	{
		return View::make('Admin.User.views.create');
	}

	public function store()
	{
		if ($this->create_validation->fails()) {
		  return Redirect::route('user.create')
		  ->withInput()
		  ->withErrors($this->create_validation->errors());
		}

		$this->gestion->store();

		return Redirect::route('user.index')
		->withInput()
		->with('success', 'L\'utilisateur a bien été créé.');	
	}

	public function show($id)
	{
		return View::make('Admin.User.views.show',  $this->gestion->show($id));
	}

	public function edit($id)
	{
		return View::make('Admin.User.views.edit',  $this->gestion->edit($id));
	}

	public function update($id)
	{
		if ($this->update_validation->fails($id)) {
		  return Redirect::route('user.edit', array($id))
		  ->withInput()
		  ->withErrors($this->update_validation->errors());
		}

		if($this->gestion->update($id)) {
			return Redirect::route('user.index')->with('success', 'Les données ont bien été mises à jour.');
		} 

		return Redirect::route('user.edit', array($id))->with('error', 'La mise à jour a échoué.');
	}

	public function destroy($id)
	{
		if(Request::ajax()) 
		{
			$this->gestion->destroy($id);
			return Response::make($id, 200);
		}
	}

}
