<?php namespace Lib\User\Account;

use Lib\User\Account\ProfilValidator as ProfilValidator;
use Lib\User\Account\PasswordValidator as PasswordValidator;
use Lib\User\Account\AccountGestion as AccountGestion;
use View, Redirect, Session;

class AccountController extends \Lib\Shared\BaseController {

	protected $profil_validation;
	protected $password_validation;
	protected $gestion;

	public function __construct(
		ProfilValidator $profil_validation,	
		PasswordValidator $password_validation,
		AccountGestion $gestion)
	{
		parent::__construct();
		$this->profil_validation = $profil_validation;
		$this->password_validation = $password_validation;
		$this->gestion = $gestion;
	}

	public function getIndex()
	{
		return View::make('User.Account.form', array('user' => $this->gestion->getUser()));
	}

	public function postProfil($id)
	{
		if($this->profil_validation->fails($id)) {
		  return Redirect::to('account')
		  ->withInput()
		  ->withErrors($this->profil_validation->errors());
		}		
		
		if($this->gestion->update()) {
			Session::flash('success', trans('user.donnees_a_jour'));
		} else {
			Session::flash('error', trans('user.mise_a_jour_echouee'));
		}

		return Redirect::to('account')->withInput();
	}

	public function postPassword()
	{
		if($this->password_validation->fails()) {
		  return Redirect::to('account')
		  ->with('pass', 'actif')
		  ->withErrors($this->password_validation->errors());
		}	

		if(!$this->gestion->checkPassword())	{
		  return Redirect::to('account')
		  ->with('pass', 'actif')
		  ->withErrors(array('old_password' => trans('user.ancien_passe_pas_bon')));			
		}

		if($this->gestion->update())	{
			Session::flash('success', trans('user.passe_change'));
		}	else {
			Session::flash('error', trans('user.passe_pas_change'));
		}
		return Redirect::to('account')->with('pass', 'actif');
	}

}
